@@ -9,7 +9,7 @@ from pydantic import AnyUrl, BeforeValidator, TypeAdapter
 from mteb.abstasks.AbsTask import AbsTask
 from mteb.load_results.benchmark_results import BenchmarkResults
 from mteb.load_results.load_results import load_results
-from mteb.overview import get_tasks
+from mteb.overview import MTEBTasks, get_tasks
 
 http_url_adapter = TypeAdapter(AnyUrl)
 UrlString = Annotated[
@@ -123,80 +123,82 @@ MTEB_EN = Benchmark(
 
 MTEB_ENG_CLASSIC = Benchmark(
     name="MTEB(eng, classic)",
-    tasks=get_tasks(
-        tasks=[
-            "AmazonCounterfactualClassification",
-            "AmazonPolarityClassification",
-            "AmazonReviewsClassification",
-            "ArguAna",
-            "ArxivClusteringP2P",
-            "ArxivClusteringS2S",
-            "AskUbuntuDupQuestions",
-            "BIOSSES",
-            "Banking77Classification",
-            "BiorxivClusteringP2P",
-            "BiorxivClusteringS2S",
-            "CQADupstackAndroidRetrieval",
-            "CQADupstackEnglishRetrieval",
-            "CQADupstackGamingRetrieval",
-            "CQADupstackGisRetrieval",
-            "CQADupstackMathematicaRetrieval",
-            "CQADupstackPhysicsRetrieval",
-            "CQADupstackProgrammersRetrieval",
-            "CQADupstackStatsRetrieval",
-            "CQADupstackTexRetrieval",
-            "CQADupstackUnixRetrieval",
-            "CQADupstackWebmastersRetrieval",
-            "CQADupstackWordpressRetrieval",
-            "ClimateFEVER",
-            "DBPedia",
-            "EmotionClassification",
-            "FEVER",
-            "FiQA2018",
-            "HotpotQA",
-            "ImdbClassification",
-            "MSMARCO",
-            "MTOPDomainClassification",
-            "MTOPIntentClassification",
-            "MassiveIntentClassification",
-            "MassiveScenarioClassification",
-            "MedrxivClusteringP2P",
-            "MedrxivClusteringS2S",
-            "MindSmallReranking",
-            "NFCorpus",
-            "NQ",
-            "QuoraRetrieval",
-            "RedditClustering",
-            "RedditClusteringP2P",
-            "SCIDOCS",
-            "SICK-R",
-            "STS12",
-            "STS13",
-            "STS14",
-            "STS15",
-            "STS16",
-            "STS17",
-            "STS22",
-            "STSBenchmark",
-            "SciDocsRR",
-            "SciFact",
-            "SprintDuplicateQuestions",
-            "StackExchangeClustering",
-            "StackExchangeClusteringP2P",
-            "StackOverflowDupQuestions",
-            "SummEval",
-            "TRECCOVID",
-            "Touche2020",
-            "ToxicConversationsClassification",
-            "TweetSentimentExtractionClassification",
-            "TwentyNewsgroupsClustering",
-            "TwitterSemEval2015",
-            "TwitterURLCorpus",
-        ],
-        languages=["eng"],
-        eval_splits=["test"],
+    tasks=MTEBTasks(
+        get_tasks(
+            tasks=[
+                "AmazonCounterfactualClassification",
+                "AmazonPolarityClassification",
+                "AmazonReviewsClassification",
+                "ArguAna",
+                "ArxivClusteringP2P",
+                "ArxivClusteringS2S",
+                "AskUbuntuDupQuestions",
+                "BIOSSES",
+                "Banking77Classification",
+                "BiorxivClusteringP2P",
+                "BiorxivClusteringS2S",
+                "CQADupstackAndroidRetrieval",
+                "CQADupstackEnglishRetrieval",
+                "CQADupstackGamingRetrieval",
+                "CQADupstackGisRetrieval",
+                "CQADupstackMathematicaRetrieval",
+                "CQADupstackPhysicsRetrieval",
+                "CQADupstackProgrammersRetrieval",
+                "CQADupstackStatsRetrieval",
+                "CQADupstackTexRetrieval",
+                "CQADupstackUnixRetrieval",
+                "CQADupstackWebmastersRetrieval",
+                "CQADupstackWordpressRetrieval",
+                "ClimateFEVER",
+                "DBPedia",
+                "EmotionClassification",
+                "FEVER",
+                "FiQA2018",
+                "HotpotQA",
+                "ImdbClassification",
+                "MTOPDomainClassification",
+                "MTOPIntentClassification",
+                "MassiveIntentClassification",
+                "MassiveScenarioClassification",
+                "MedrxivClusteringP2P",
+                "MedrxivClusteringS2S",
+                "MindSmallReranking",
+                "NFCorpus",
+                "NQ",
+                "QuoraRetrieval",
+                "RedditClustering",
+                "RedditClusteringP2P",
+                "SCIDOCS",
+                "SICK-R",
+                "STS12",
+                "STS13",
+                "STS14",
+                "STS15",
+                "STS16",
+                "STS17",
+                "STS22",
+                "STSBenchmark",
+                "SciDocsRR",
+                "SciFact",
+                "SprintDuplicateQuestions",
+                "StackExchangeClustering",
+                "StackExchangeClusteringP2P",
+                "StackOverflowDupQuestions",
+                "SummEval",
+                "TRECCOVID",
+                "Touche2020",
+                "ToxicConversationsClassification",
+                "TweetSentimentExtractionClassification",
+                "TwentyNewsgroupsClustering",
+                "TwitterSemEval2015",
+                "TwitterURLCorpus",
+            ],
+            languages=["eng"],
+            eval_splits=["test"],
+        )
+        + get_tasks(tasks=["MSMARCO"], languages=["eng"], eval_splits=["dev"])
     ),
-    description="The original English benchmarks by Muennighoff et al., (2023).",
+    description="The original English benchmark by Muennighoff et al., (2023).",
     citation="""@inproceedings{muennighoff-etal-2023-mteb,
     title = "{MTEB}: Massive Text Embedding Benchmark",
     author = "Muennighoff, Niklas  and
@@ -436,6 +438,39 @@ CoIR = Benchmark(
     }""",
 )
 
+RAR_b = Benchmark(
+    name="RAR-b",
+    tasks=get_tasks(
+        tasks=[
+            "ARCChallenge",
+            "AlphaNLI",
+            "HellaSwag",
+            "WinoGrande",
+            "PIQA",
+            "SIQA",
+            "Quail",
+            "SpartQA",
+            "TempReasonL1",
+            "TempReasonL2Pure",
+            "TempReasonL2Fact",
+            "TempReasonL2Context",
+            "TempReasonL3Pure",
+            "TempReasonL3Fact",
+            "TempReasonL3Context",
+            "RARbCode",
+            "RARbMath",
+        ]
+    ),
+    description="A benchmark to evaluate reasoning capabilities of retrievers.",
+    reference="https://arxiv.org/abs/2404.06347",
+    citation="""@article{xiao2024rar,
+      title={RAR-b: Reasoning as Retrieval Benchmark},
+      author={Xiao, Chenghao and Hudson, G Thomas and Al Moubayed, Noura},
+      journal={arXiv preprint arXiv:2404.06347},
+      year={2024}
+    }""",
+)
+
 MTEB_FRA = Benchmark(
     name="MTEB(fra)",
     tasks=get_tasks(
@@ -725,7 +760,6 @@ MTEB_multilingual = Benchmark(
             "SpartQA",
             "TempReasonL1",
             "TRECCOVID",
-            "CUREv1",
             "WinoGrande",
             "BelebeleRetrieval",
             "MLQARetrieval",
@@ -979,3 +1013,27 @@ BRIGHT = Benchmark(
   year={2024}
 }""",
 )
+
+NANOBEIR = Benchmark(
+    name="NanoBEIR",
+    tasks=get_tasks(
+        tasks=[
+            "NanoArguAnaRetrieval",
+            "NanoClimateFeverRetrieval",
+            "NanoDBPediaRetrieval",
+            "NanoFEVERRetrieval",
+            "NanoFiQA2018Retrieval",
+            "NanoHotpotQARetrieval",
+            "NanoMSMARCORetrieval",
+            "NanoNFCorpusRetrieval",
+            "NanoNQRetrieval",
+            "NanoQuoraRetrieval",
+            "NanoSCIDOCSRetrieval",
+            "NanoSciFactRetrieval",
+            "NanoTouche2020Retrieval",
+        ],
+    ),
+    description="A benchmark to evaluate with subsets of BEIR datasets to use less computational power",
+    reference="https://huggingface.co/collections/zeta-alpha-ai/nanobeir-66e1a0af21dfd93e620cd9f6",
+    citation=None,
+)
