@@ -468,7 +468,36 @@ class TaskResult(BaseModel):
                         values.append(getter(scores))
                         break
 
-            return aggregation(values)
+        return aggregation(values)
+
+    def get_score_fast(self, splits, languages):
+        """Sped up version of get_score that will be used if no aggregation, script or getter needs to be specified."""
+        if splits is None:
+            splits = self.scores
+        val_sum = 0
+        n_val = 0
+        for split in splits:
+            if split not in self.scores:
+                raise ValueError(f"Split missing from scores: {split}")
+                continue
+            for scores in self.scores[split]:
+                langs = scores["languages"]
+                hf_subset = scores["hf_subset"]
+                main_score = scores.get("main_score", None)
+                if main_score is None:
+                    raise ValueError(f"Missing main score for subset: {hf_subset}")
+                if languages is None:
+                    val_sum += main_score
+                    n_val += 1
+                    continue
+                for lang in langs:
+                    if lang.split("-")[0] in languages:
+                        val_sum += main_score
+                        n_val += 1
+                        break
+        if n_val == 0:
+            raise ValueError("No splits had scores for the specified languages.")
+        return val_sum / n_val
 
     @classmethod
     def from_validated(cls, **data) -> TaskResult:
@@ -477,7 +506,23 @@ class TaskResult(BaseModel):
     def __repr__(self) -> str:
         return f"TaskResult(task_name={self.task_name}, scores=...)"
 
-    def validate_and_filter_scores(self, task: AbsTask | None = None) -> AbsTask:
+    def only_main_score(self) -> TaskResult:
+        new_scores = {}
+        for split in self.scores:
+            new_scores[split] = []
+            for subset_scores in self.scores[split]:
+                new_scores[split].append(
+                    {
+                        "hf_subset": subset_scores.get("hf_subset", "default"),
+                        "main_score": subset_scores.get("main_score", np.nan),
+                        "languages": subset_scores.get("languages", []),
+                    }
+                )
+        new_res = {**self.to_dict(), "scores": new_scores}
+        new_res = TaskResult.from_validated(**new_res)
+        return new_res
+
+    def validate_and_filter_scores(self, task: AbsTask | None = None) -> TaskResult:
         """This ensures that the scores are correct for the given task, by removing any splits besides those specified in the task metadata.
         Additionally it also ensure that all of the splits required as well as the languages are present in the scores.
         Returns new TaskResult object.
@@ -511,12 +556,21 @@ class TaskResult(BaseModel):
                 new_scores[split].append(_scores)
                 seen_subsets.add(_scores["hf_subset"])
             if seen_subsets != hf_subsets:
-                raise ValueError(
-                    f"Missing subsets {hf_subsets - seen_subsets} for split {split}"
+                missing_subsets = hf_subsets - seen_subsets
+                if len(missing_subsets) > 2:
+                    subset1, subset2 = list(missing_subsets)[:2]
+                    missing_subsets_str = f"{{'{subset1}', '{subset2}', ...}}"
+                else:
+                    missing_subsets_str = str(missing_subsets)
+
+                logger.warning(
+                    f"{task.metadata.name}: Missing subsets {missing_subsets_str} for split {split}"
                 )
             seen_splits.add(split)
         if seen_splits != set(splits):
-            raise ValueError(f"Missing splits {set(splits) - seen_splits}")
+            logger.warning(
+                f"{task.metadata.name}: Missing splits {set(splits) - seen_splits}"
+            )
         new_res = {**self.to_dict(), "scores": new_scores}
         new_res = TaskResult.from_validated(**new_res)
         return new_res
