@@ -24,7 +24,7 @@ def instruct_wrapper(
         from gritlm import GritLM
     except ImportError:
         raise ImportError(
-            f"Please install `pip install gritlm` to use {model_name_or_path}."
+            f"Please install `pip install mteb[gritlm]` to use {model_name_or_path}."
         )
 
     class InstructWrapper(GritLM, Wrapper):
@@ -47,6 +47,11 @@ def instruct_wrapper(
                     "No instruction template provided. Instructions will be used as-is."
                 )
 
+            if "gte-Qwen" in model_name_or_path:
+                logger.warning(
+                    "Instructions are used in both query and docs, which may cause performance discrepancies from the original implementation."
+                )
+
             self.instruction_template = instruction_template
             super().__init__(model_name_or_path=model_name_or_path, mode=mode, **kwargs)
 
@@ -61,7 +66,7 @@ def instruct_wrapper(
             instruction = self.get_instruction(task_name, prompt_type)
 
             if self.instruction_template:
-                instruction = self.format_instruction(instruction)
+                instruction = self.format_instruction(instruction, prompt_type)
 
             logger.info(f"Using instruction: '{instruction}' for task: '{task_name}'")
             embeddings = super().encode(
@@ -72,9 +77,4 @@ def instruct_wrapper(
                 embeddings = embeddings.cpu().detach().float().numpy()
             return embeddings
 
-        def format_instruction(self, instruction: str) -> str:
-            if isinstance(self.instruction_template, str):
-                return self.instruction_template.format(instruction=instruction)
-            return self.instruction_template(instruction)
-
     return InstructWrapper(model_name_or_path, mode, instruction_template, **kwargs)
