@@ -4,11 +4,7 @@ import logging
 from functools import partial
 
 import torch
-from transformers import (
-    AutoModelForCausalLM,
-    AutoModelForSeq2SeqLM,
-    AutoTokenizer,
-)
+from transformers import AutoModelForCausalLM, AutoModelForSeq2SeqLM, AutoTokenizer
 
 from mteb.model_meta import ModelMeta
 from mteb.models.rerankers_custom import RerankerWrapper, _loader
@@ -94,8 +90,10 @@ class MonoT5Reranker(RerankerWrapper):
                 token_true_id = tokenizer.get_vocab()[token_true]
                 return token_false_id, token_true_id
             else:
-                raise Exception(f"We don't know the indexes for the non-relevant/relevant tokens for\
-                        the checkpoint {model_name_or_path} and you did not provide any.")
+                raise Exception(
+                    f"We don't know the indexes for the non-relevant/relevant tokens for\
+                        the checkpoint {model_name_or_path} and you did not provide any."
+                )
         else:
             token_false_id = tokenizer.get_vocab()[token_false]
             token_true_id = tokenizer.get_vocab()[token_true]
@@ -103,7 +101,12 @@ class MonoT5Reranker(RerankerWrapper):
 
     @torch.inference_mode()
     def predict(self, input_to_rerank, **kwargs):
-        queries, passages, instructions = list(zip(*input_to_rerank))
+        inputs = list(zip(*input_to_rerank))
+        if len(input_to_rerank[0]) == 2:
+            queries, passages = inputs
+            instructions = None
+        else:
+            queries, passages, instructions = inputs
 
         if instructions is not None and instructions[0] is not None:
             queries = [f"{q} {i}".strip() for i, q in zip(instructions, queries)]
@@ -192,7 +195,13 @@ Relevant: """
 
     @torch.inference_mode()
     def predict(self, input_to_rerank, **kwargs):
-        queries, passages, instructions = list(zip(*input_to_rerank))
+        inputs = list(zip(*input_to_rerank))
+        if len(input_to_rerank[0]) == 2:
+            queries, passages = inputs
+            instructions = None
+        else:
+            queries, passages, instructions = inputs
+
         if instructions is not None and instructions[0] is not None:
             # logger.info(f"Adding instructions to LLAMA queries")
             queries = [
@@ -276,7 +285,7 @@ Passage: {text}"""
 
 
 monot5_small = ModelMeta(
-    loader=partial(
+    loader=partial(  # type: ignore
         _loader,
         wrapper=MonoT5Reranker,
         model_name_or_path="castorini/monot5-small-msmarco-10k",
@@ -290,7 +299,7 @@ monot5_small = ModelMeta(
 )
 
 monot5_base = ModelMeta(
-    loader=partial(
+    loader=partial(  # type: ignore
         _loader,
         wrapper=MonoT5Reranker,
         model_name_or_path="castorini/monot5-base-msmarco-10k",
@@ -304,7 +313,7 @@ monot5_base = ModelMeta(
 )
 
 monot5_large = ModelMeta(
-    loader=partial(
+    loader=partial(  # type: ignore
         _loader,
         wrapper=MonoT5Reranker,
         model_name_or_path="castorini/monot5-large-msmarco-10k",
@@ -318,7 +327,7 @@ monot5_large = ModelMeta(
 )
 
 monot5_3b = ModelMeta(
-    loader=partial(
+    loader=partial(  # type: ignore
         _loader,
         wrapper=MonoT5Reranker,
         model_name_or_path="castorini/monot5-3b-msmarco-10k",
@@ -332,7 +341,7 @@ monot5_3b = ModelMeta(
 )
 
 flant5_base = ModelMeta(
-    loader=partial(
+    loader=partial(  # type: ignore
         _loader,
         wrapper=FLANT5Reranker,
         model_name_or_path="google/flan-t5-base",
@@ -343,10 +352,22 @@ flant5_base = ModelMeta(
     open_weights=True,
     revision="7bcac572ce56db69c1ea7c8af255c5d7c9672fc2",
     release_date="2022-10-21",
+    training_datasets={
+        "svakulenk0/qrecc": ["train"],
+        "taskmaster2": ["train"],
+        "djaym7/wiki_dialog": ["train"],
+        "deepmind/code_contests": ["train"],
+        "lambada": ["train"],
+        "gsm8k": ["train"],
+        "aqua_rat": ["train"],
+        "esnli": ["train"],
+        "quasc": ["train"],
+        "qed": ["train"],
+    },
 )
 
 flant5_large = ModelMeta(
-    loader=partial(
+    loader=partial(  # type: ignore
         _loader,
         wrapper=FLANT5Reranker,
         model_name_or_path="google/flan-t5-large",
@@ -357,10 +378,22 @@ flant5_large = ModelMeta(
     open_weights=True,
     revision="0613663d0d48ea86ba8cb3d7a44f0f65dc596a2a",
     release_date="2022-10-21",
+    training_datasets={
+        "svakulenk0/qrecc": ["train"],
+        "taskmaster2": ["train"],
+        "djaym7/wiki_dialog": ["train"],
+        "deepmind/code_contests": ["train"],
+        "lambada": ["train"],
+        "gsm8k": ["train"],
+        "aqua_rat": ["train"],
+        "esnli": ["train"],
+        "quasc": ["train"],
+        "qed": ["train"],
+    },
 )
 
 flant5_xl = ModelMeta(
-    loader=partial(
+    loader=partial(  # type: ignore
         _loader,
         wrapper=FLANT5Reranker,
         model_name_or_path="google/flan-t5-xl",
@@ -371,10 +404,22 @@ flant5_xl = ModelMeta(
     open_weights=True,
     revision="7d6315df2c2fb742f0f5b556879d730926ca9001",
     release_date="2022-10-21",
+    training_datasets={
+        "svakulenk0/qrecc": ["train"],
+        "taskmaster2": ["train"],
+        "djaym7/wiki_dialog": ["train"],
+        "deepmind/code_contests": ["train"],
+        "lambada": ["train"],
+        "gsm8k": ["train"],
+        "aqua_rat": ["train"],
+        "esnli": ["train"],
+        "quasc": ["train"],
+        "qed": ["train"],
+    },
 )
 
 flant5_xxl = ModelMeta(
-    loader=partial(
+    loader=partial(  # type: ignore
         _loader,
         wrapper=FLANT5Reranker,
         model_name_or_path="google/flan-t5-xxl",
@@ -385,11 +430,23 @@ flant5_xxl = ModelMeta(
     open_weights=True,
     revision="ae7c9136adc7555eeccc78cdd960dfd60fb346ce",
     release_date="2022-10-21",
+    training_datasets={
+        "svakulenk0/qrecc": ["train"],
+        "taskmaster2": ["train"],
+        "djaym7/wiki_dialog": ["train"],
+        "deepmind/code_contests": ["train"],
+        "lambada": ["train"],
+        "gsm8k": ["train"],
+        "aqua_rat": ["train"],
+        "esnli": ["train"],
+        "quasc": ["train"],
+        "qed": ["train"],
+    },
 )
 
 
 llama2_7b = ModelMeta(
-    loader=partial(
+    loader=partial(  # type: ignore
         _loader,
         wrapper=LlamaReranker,
         model_name_or_path="meta-llama/Llama-2-7b-hf",
@@ -403,7 +460,7 @@ llama2_7b = ModelMeta(
 )
 
 llama2_7b_chat = ModelMeta(
-    loader=partial(
+    loader=partial(  # type: ignore
         _loader,
         wrapper=LlamaReranker,
         model_name_or_path="meta-llama/Llama-2-7b-chat-hf",
@@ -417,7 +474,7 @@ llama2_7b_chat = ModelMeta(
 )
 
 mistral_7b = ModelMeta(
-    loader=partial(
+    loader=partial(  # type: ignore
         _loader,
         wrapper=MistralReranker,
         model_name_or_path="mistralai/Mistral-7B-Instruct-v0.2",
@@ -431,7 +488,7 @@ mistral_7b = ModelMeta(
 )
 
 followir_7b = ModelMeta(
-    loader=partial(
+    loader=partial(  # type: ignore
         _loader,
         wrapper=FollowIRReranker,
         model_name_or_path="jhu-clsp/FollowIR-7B",
@@ -442,6 +499,7 @@ followir_7b = ModelMeta(
     open_weights=True,
     revision="4d25d437e38b510c01852070c0731e8f6e1875d1",
     release_date="2024-04-29",
+    training_datasets={"jhu-clsp/FollowIR-train": ["train"]},
 )
 
 
@@ -550,7 +608,7 @@ mt5_languages = [
 ]
 
 mt5_base_mmarco_v2 = ModelMeta(
-    loader=partial(
+    loader=partial(  # type: ignore
         _loader,
         wrapper=MonoT5Reranker,
         model_name_or_path="unicamp-dl/mt5-base-mmarco-v2",
@@ -561,10 +619,11 @@ mt5_base_mmarco_v2 = ModelMeta(
     open_weights=True,
     revision="cc0a949b9f21efcaba45c8cabb998ad02ce8d4e7",
     release_date="2022-01-05",
+    training_datasets={"msmarco": ["train"]},
 )
 
 mt5_13b_mmarco_100k = ModelMeta(
-    loader=partial(
+    loader=partial(  # type: ignore
         _loader,
         wrapper=MonoT5Reranker,
         model_name_or_path="unicamp-dl/mt5-13b-mmarco-100k",
